@@ -1,5 +1,6 @@
 import os
 import sys
+from pathlib import Path
 from typing import Iterator, List, Optional
 
 import log
@@ -363,7 +364,6 @@ class Config:
     ) -> List[str]:
         """Get a filtered subset of sources."""
         names_list = list(names)
-
         if not names_list and not skip_default_group:
             names_list.append(self.default_group)
 
@@ -376,8 +376,12 @@ class Config:
             [source.name for source in sources if source.name in names_list]
         )
 
+        # Fall back to all sources if allowed
         if not sources_filter:
-            sources_filter = [source.name for source in sources if source.name]
+            if names and names_list != ["all"]:
+                log.warn(f"No dependencies match: {' '.join(names)}")
+            else:
+                sources_filter = [source.name for source in sources if source.name]
 
         return list(set(sources_filter))
 
@@ -430,7 +434,7 @@ def find_nested_configs(
         if name.startswith("."):
             continue
         path = os.path.join(root, name)
-        if os.path.isdir(path) and path not in skip_paths:
+        if os.path.isdir(path) and path not in skip_paths and not os.path.islink(path):
             config = load_config(path, search=False)
             if config:
                 configs.append(config)
@@ -461,3 +465,17 @@ def _valid_filename(filename):
     if name.startswith("."):
         name = name[1:]
     return name in {"gitman", "gdm"} and ext in {".yml", ".yaml"}
+
+
+def filter_nested_configs(
+    top_level_config: Config, nested_configs: List[Config]
+) -> List[Config]:
+    """Filter subdirectories inside of parent config."""
+    configs = []
+    config_location_path = Path(top_level_config.location_path)
+    for nested_config in nested_configs:
+        nested_config_root = Path(nested_config.location_path)
+        if config_location_path in nested_config_root.parents:
+            configs.append(nested_config)
+
+    return configs
